@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2012-2023 Univention GmbH
+# Copyright 2012-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -33,12 +33,9 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-import locale
 import subprocess
 import time
 
-import six
-
 from univention.lib.i18n import Translation
 from univention.management.console.error import ServerError
 from univention.management.console.log import MODULE
@@ -53,21 +50,6 @@ CMD_ENABLE_EXEC_WITH_RESTART = '/usr/share/univention-updater/enable-apache2-umc
 CMD_DISABLE_EXEC = '/usr/share/univention-updater/disable-apache2-umc'
 
 
-class MessageSanitizer(StringSanitizer):
-
-    def _sanitize(self, value, name, further_args):
-        value = super(MessageSanitizer, self)._sanitize(value, name, further_args)
-        if six.PY2 and isinstance(value, six.text_type):
-            # unicodestr -> bytestr (for use in command strings)
-            for encoding in (locale.getpreferredencoding(), 'UTF-8', 'ISO8859-1'):
-                try:
-                    value = value.encode(encoding)
-                    break
-                except UnicodeEncodeError:
-                    pass
-        return value
-
-
 class Server(object):
 
     def restart_isNeeded(self, request):
@@ -86,14 +68,14 @@ class Server(object):
         # (disable first to make sure the services are restarted)
         subprocess.call(CMD_DISABLE_EXEC)
         p = subprocess.Popen(CMD_ENABLE_EXEC_WITH_RESTART, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
-        out, err = p.communicate()
+        out, _err = p.communicate()
         MODULE.info('enabling server restart:\n%s' % (out.decode('utf-8')))
 
     @simple_response
     def ping(self):
         return {"success": True}
 
-    @sanitize(message=MessageSanitizer(default=''))
+    @sanitize(message=StringSanitizer(default=''))
     def reboot(self, request):
         message = _('The system will now be restarted')
         if request.options['message']:
@@ -104,7 +86,7 @@ class Server(object):
 
         self.finished(request.id, None, message)
 
-    @sanitize(message=MessageSanitizer(default=''))
+    @sanitize(message=StringSanitizer(default=''))
     def shutdown(self, request):
         message = _('The system will now be shut down')
         if request.options['message']:
